#ifdef __cplusplus 
extern "C" {
#endif

#define TTY_COLOR_HIGHLIGHT TTY_COLOR_YELLOW

#define SCORE_GAP_LEADING -0.005
#define SCORE_GAP_TRAILING -0.005
#define SCORE_GAP_INNER -0.01
#define SCORE_MATCH_CONSECUTIVE 1.0
#define SCORE_MATCH_SLASH 0.9
#define SCORE_MATCH_WORD 0.8
#define SCORE_MATCH_CAPITAL 0.7
#define SCORE_MATCH_DOT 0.6

/* Time (in ms) to wait for additional bytes of an escape sequence */
#define KEYTIMEOUT 25

#define DEFAULT_TTY "/dev/tty"
#define DEFAULT_PROMPT "> "
#define DEFAULT_NUM_LINES 10
#define DEFAULT_WORKERS 0
#define DEFAULT_SHOW_INFO 0

#ifdef __cplusplus 
}
#endif
